Crate nostd_io Copy item path Source prelude The I/O Prelude. const_error Experimental Creates a new I/O error from a known kind of error and a string literal. BufReader The BufReader<R> struct adds buffering to any reader. BufWriter Wraps a writer and buffers its output. Bytes An iterator over u8 values of a reader. Chain Adapter to chain together two readers. Cursor A Cursor wraps an in-memory buffer and provides it with a
Seek implementation. Empty Empty ignores any data written via Write , and will always be empty
(returning zero bytes) when read via Read .Error The error type for I/O operations of the Read , Write , Seek , and
associated traits. IntoInnerError An error returned by BufWriter::into_inner which combines an error that
happened while writing out the buffer, and the buffered writer object
which may be used to recover from the condition. IoSlice A buffer type used with Write::write_vectored. IoSliceMut A buffer type used with Read::read_vectored. LineWriter Wraps a writer and buffers output to it, flushing whenever a newline
(0x0a, '\n') is detected. Lines An iterator over the lines of an instance of BufRead. PipeReader Read end of an anonymous pipe. PipeWriter Write end of an anonymous pipe. Repeat A reader which yields one byte over and over and over and over and over and… Sink A writer which will move data into the void. Split An iterator over the contents of an instance of BufRead split on a
particular byte. Stderr A handle to the standard error stream of a process. StderrLock A locked reference to the Stderr handle. Stdin A handle to the standard input stream of a process. StdinLock A locked reference to the Stdin handle. Stdout A handle to the global standard output stream of the current process. StdoutLock A locked reference to the Stdout handle. Take Reader adapter which limits the bytes read from an underlying reader. WriterPanicked Error returned for the buffered data from BufWriter::into_parts, when the underlying
writer has previously panicked. Contains the (possibly partly written) buffered data. BorrowedBuf Experimental A borrowed byte buffer which is incrementally filled and initialized. BorrowedCursor Experimental A writeable view of the unfilled portion of a BorrowedBuf . ErrorKind A list specifying general categories of I/O error. SeekFrom Enumeration of possible methods to seek within an I/O object. BufRead A BufRead is a type of Reader which has an internal buffer, allowing it
to perform extra ways of reading. IsTerminal Trait to determine if a descriptor/handle refers to a terminal/tty. Read The Read trait allows for reading bytes from a source. Seek The Seek trait provides a cursor which can be moved within a stream of
bytes. Write A trait for objects which are byte-oriented sinks. copy Copies the entire contents of a reader into a writer. empty Creates a value that is always at EOF for reads, and ignores all data written. pipe Creates an anonymous pipe. read_to_string Reads all bytes from a reader into a new String . repeat Creates an instance of a reader that infinitely repeats one byte. sink Creates an instance of a writer which will successfully consume all data. stderr Constructs a new handle to the standard error of the current process. stdin Constructs a new handle to the standard input of the current process. stdout Constructs a new handle to the standard output of the current process. Result A specialized Result type for I/O operations. RawOsError Experimental The type of raw OS error codes returned by Error::raw_os_error .